@@ -244,12 +244,15 @@ fn build_root(cmd: &Command, wrap_width: Option<usize>) -> String {
 
     format!(
         r#"# ARGC-BUILD {{
-# This block was generated by argc (https://github.com/sigoden/argc)
+# This block was generated by argc (https://github.com/sigoden/argc).
 # Modifying it manually is not recommended
 
 _argc_run() {{
     if [[ "${{1:-}}" == "___internal___" ]]; then
-        _argc_die "error: no supported param"
+        _argc_die "error: unsupported ___internal___ command"
+    fi
+    if [[ "${{OS:-}}" == "Windows_NT" ]] && [[ -n "${{MSYSTEM:-}}" ]]; then
+        set -o igncr
     fi
     argc__args=("$(basename "$0" .sh)" "$@")
     argc__positionals=()
